#' @name phylo_Vign
#' @title A phylogenetic reconstuction to run the vignette
#' @description An example phylogeny in the right format for secsse
#' @format Phylogenetic tree in format nexus, rooted, including branch lengths
NULL


#' @name traitinfo
#' @title A table with trait info to run the vignette
#' @description An example of trait information in the right format for secsse
#' @format A data frame where each species has a trait state associated
NULL


#' @name example_phy_GeoSSE
#' @title A phylogeny with traits at the tips
#' @description An example phylogeny for testing purposes
#' @format A phylogeny as created by GeoSSE (diversitree)
"phy"